using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.CommandWpf;
using GalaSoft.MvvmLight.Messaging;
using WpfNavigation.Messages;

namespace WpfNavigation.ViewModel
{
    public class MainViewModel : ViewModelBase
    {
        private AViewModel _currentPageViewModel;

        private readonly ObservableCollection<AViewModel> _viewModelList = new ObservableCollection<AViewModel>();

        public ObservableCollection<AViewModel> ViewModelList => _viewModelList;

        public AViewModel CurrentPageViewModel
        {
            get => _currentPageViewModel;
            set => Set(() => CurrentPageViewModel, ref _currentPageViewModel, value);
        }

        public RelayCommand<AViewModel> ChangePageCommand { get; private set; }

        public MainViewModel()
        {
            ChangePageCommand = new RelayCommand<AViewModel>(ChangePageAction);

            ViewModelLocator.Instance.View1.MainViewModel = this;

            _viewModelList.Add(ViewModelLocator.Instance.View1);
            _viewModelList.Add(ViewModelLocator.Instance.View2);
            _viewModelList.Add(ViewModelLocator.Instance.View3);

            _currentPageViewModel = _viewModelList[0];

            //register message for switching the view
            Messenger.Default.Register<ChangeViewMessage>(this, (msg) =>
            {
                CurrentPageViewModel = msg.TargetViewModel;
            });
        }

        private void ChangePageAction(AViewModel viewModel)
        {
            CurrentPageViewModel = ViewModelList.FirstOrDefault(vm => vm == viewModel);
        }
    }
}